""" Contains all the data models used in inputs/outputs """

from online_pvt_api_client.models.api_call_result import ApiCallResult
from online_pvt_api_client.models.api_fluid import ApiFluid
from online_pvt_api_client.models.api_fluid_component_block import ApiFluidComponentBlock
from online_pvt_api_client.models.api_fluid_kij import ApiFluidKij
from online_pvt_api_client.models.api_fluid_polymer_component import ApiFluidPolymerComponent
from online_pvt_api_client.models.api_fluid_pseudo_component import ApiFluidPseudoComponent
from online_pvt_api_client.models.api_fluid_standard_component import ApiFluidStandardComponent
from online_pvt_api_client.models.api_output_calculation_result_phase import ApiOutputCalculationResultPhase
from online_pvt_api_client.models.api_output_calculation_result_phase_composition import ApiOutputCalculationResultPhaseComposition
from online_pvt_api_client.models.api_output_calculation_result_phase_polymer_moment import ApiOutputCalculationResultPhasePolymerMoment
from online_pvt_api_client.models.api_output_calculation_result_phase_polymer_moments import ApiOutputCalculationResultPhasePolymerMoments
from online_pvt_api_client.models.api_output_calculation_result_point import ApiOutputCalculationResultPoint
from online_pvt_api_client.models.api_output_phasediagram import ApiOutputPhasediagram
from online_pvt_api_client.models.api_output_phasediagram_point import ApiOutputPhasediagramPoint
from online_pvt_api_client.models.api_output_unflashed_property_result import ApiOutputUnflashedPropertyResult
from online_pvt_api_client.models.api_output_unflashed_property_result_ideal import ApiOutputUnflashedPropertyResultIdeal
from online_pvt_api_client.models.api_output_unflashed_property_result_residual import ApiOutputUnflashedPropertyResultResidual
from online_pvt_api_client.models.api_value_floating_with_out_units import ApiValueFloatingWithOutUnits
from online_pvt_api_client.models.api_value_floating_with_out_units_name import ApiValueFloatingWithOutUnitsName
from online_pvt_api_client.models.api_value_floating_with_units import ApiValueFloatingWithUnits
from online_pvt_api_client.models.api_value_with_units_composition_array import ApiValueWithUnitsCompositionArray
from online_pvt_api_client.models.api_value_with_units_density import ApiValueWithUnitsDensity
from online_pvt_api_client.models.api_value_with_units_enthalpy import ApiValueWithUnitsEnthalpy
from online_pvt_api_client.models.api_value_with_units_entropy import ApiValueWithUnitsEntropy
from online_pvt_api_client.models.api_value_with_units_pressure import ApiValueWithUnitsPressure
from online_pvt_api_client.models.api_value_with_units_temperature import ApiValueWithUnitsTemperature
from online_pvt_api_client.models.api_value_with_units_volume import ApiValueWithUnitsVolume
from online_pvt_api_client.models.api_value_with_units_volume_mole_percent import ApiValueWithUnitsVolumeMolePercent
from online_pvt_api_client.models.api_value_with_units_volume_weight_percent import ApiValueWithUnitsVolumeWeightPercent
from online_pvt_api_client.models.association_scheme import AssociationScheme
from online_pvt_api_client.models.calculation_block_info import CalculationBlockInfo
from online_pvt_api_client.models.calculation_composition import CalculationComposition
from online_pvt_api_client.models.cloud_point_calculation_input import CloudPointCalculationInput
from online_pvt_api_client.models.cloud_point_calculation_result import CloudPointCalculationResult
from online_pvt_api_client.models.cloud_point_calculation_type import CloudPointCalculationType
from online_pvt_api_client.models.component_type import ComponentType
from online_pvt_api_client.models.cp_model import CpModel
from online_pvt_api_client.models.distribution_model import DistributionModel
from online_pvt_api_client.models.eos_model import EosModel
from online_pvt_api_client.models.exception_info import ExceptionInfo
from online_pvt_api_client.models.flash_calculation_input import FlashCalculationInput
from online_pvt_api_client.models.flash_calculation_result import FlashCalculationResult
from online_pvt_api_client.models.flash_calculation_type import FlashCalculationType
from online_pvt_api_client.models.flashed_property_calculation_input import FlashedPropertyCalculationInput
from online_pvt_api_client.models.flashed_property_calculation_result import FlashedPropertyCalculationResult
from online_pvt_api_client.models.fluid_distribution_moment import FluidDistributionMoment
from online_pvt_api_client.models.is_alkane import IsAlkane
from online_pvt_api_client.models.message_type import MessageType
from online_pvt_api_client.models.new_fluid_input import NewFluidInput
from online_pvt_api_client.models.new_fluid_result import NewFluidResult
from online_pvt_api_client.models.phasediagram_fixed_temperature_pressure_calculation_input import (
    PhasediagramFixedTemperaturePressureCalculationInput,
)
from online_pvt_api_client.models.phasediagram_fixed_temperature_pressure_calculation_result import (
    PhasediagramFixedTemperaturePressureCalculationResult,
)
from online_pvt_api_client.models.polymer_type import PolymerType
from online_pvt_api_client.models.problem_details import ProblemDetails
from online_pvt_api_client.models.profile_information import ProfileInformation
from online_pvt_api_client.models.profile_steps import ProfileSteps
from online_pvt_api_client.models.profile_time_information import ProfileTimeInformation
from online_pvt_api_client.models.properties_calculation_type import PropertiesCalculationType
from online_pvt_api_client.models.property_reference_point import PropertyReferencePoint
from online_pvt_api_client.models.request_fluid_input import RequestFluidInput
from online_pvt_api_client.models.request_fluid_result import RequestFluidResult
from online_pvt_api_client.models.sle_point_calculation_input import SlePointCalculationInput
from online_pvt_api_client.models.sle_point_calculation_result import SlePointCalculationResult
from online_pvt_api_client.models.sle_point_calculation_type import SlePointCalculationType
from online_pvt_api_client.models.unflashed_property_calculation_input import UnflashedPropertyCalculationInput
from online_pvt_api_client.models.unflashed_property_calculation_result import UnflashedPropertyCalculationResult
from online_pvt_api_client.models.units import Units
from online_pvt_api_client.models.units_item import UnitsItem
from online_pvt_api_client.models.user_point_output import UserPointOutput
